/**
 * \file    main.c
 * \brief   The file contains the main functions of the project
 * \author  eQ-3 Entwicklung GmbH
**/
/*-----------------------------------------------------------------------------
 * Copyright 2016 eQ-3 Entwicklung GmbH
 * All Rights Reserved.
 *
 * The information contained in this file is confidential property of "eQ-3
 * Entwicklung GmbH". The use copying, transfer or disclosure is prohibited
 * except by written agreement with "eQ-3 Entwicklung GmbH".
 *---------------------------------------------------------------------------*/
/*
 * $URL$
 * $Author$
 * $Date$
 * $Revision$
 */

/** @addtogroup MAIN
 *  @{
**/
/*---------------------------------------------------------------------------*/

/**
 * Includes section -----------------------------------------------------------
**/
#include "em_emu.h"
#include "em_cmu.h"
#include "em_int.h"
#include "modules/display/15WG1/15WG1_EPD.h"
#include "modules/display/15WG1/15WG1_SPI.h"
#include "modules/init/init.h"
#include "modules/gpio/gpio.h"
#include "modules/demo/demo.h"


/**
 * Module variable section ----------------------------------------------------
**/
uint8_t Text_string_0[]= "Testfont Courier";
uint8_t Text_string_1[]= "Schrift 12 pt";
uint8_t Text_string_2[]= "Testfont Consolas";
uint8_t Text_string_3[]= "Schrift 14 pt";


/**
 *  Function section ----------------------------------------------------------
**/


/**
 * \brief Main loop
 *
 * \param none
 * \retval exit code
**/
int main( void )
{
	INIT_uc_init();                                                         // System initialization
	
	SPI_15WG1_init();                                                       // Display SPI initialization
	
	SPI_15WG1_setup(USART1_NUM, USART_ROUTE_LOCATION_0);                    // Display SPI configuration
	
	EPD_15WG1_init();			                                                  // Display initialization
	
	EPD_15WG1_Refresh(REFMODE_4);                                           // Display Refresh at the beginning
	
	EPD_15WG1_picturedemo();                                                // Demo image sequence of the display
	
	EPD_15WG1_functiondemo();	                                              // Demo display functions (strips, chessboard, etc.)																					
	 
	EPD_15WG1_Show_String(Text_string_0, (sizeof(Text_string_0)-1),COURIER, 0xb4, 0x07, BLACK_FONT); 	// Font example
	EPD_15WG1_Show_String(Text_string_1, (sizeof(Text_string_1)-1),COURIER, 0xa7, 0x09, BLACK_FONT);  // Courier 12pt
	
	EPD_15WG1_Show_String(Text_string_2, (sizeof(Text_string_2)-1),CONSOLAS, 0xb8, 0x0e, BLACK_FONT); // Consolas 14pt
	EPD_15WG1_Show_String(Text_string_3, (sizeof(Text_string_3)-1),CONSOLAS, 0xa8, 0x10, BLACK_FONT); 
		
	EPD_15WG1_Update();                                                     // After write actions into RAM update the display
}

/** \}
 * End of file
**/
