/**
 * \file    delay.c
 * \brief   The file contains some delay functions
 * \author  eQ-3 Entwicklung GmbH
**/
/*-----------------------------------------------------------------------------
 * Copyright 2016 eQ-3 Entwicklung GmbH
 * All Rights Reserved.
 *
 * The information contained in this file is confidential property of "eQ-3
 * Entwicklung GmbH". The use copying, transfer or disclosure is prohibited
 * except by written agreement with "eQ-3 Entwicklung GmbH".
 *---------------------------------------------------------------------------*/
/*
 * $URL$
 * $Author$
 * $Date$
 * $Revision$
 */

/** @addtogroup DELAY
 *  @{
**/
/*---------------------------------------------------------------------------*/

/**
 * Includes section -----------------------------------------------------------
**/

#include "../typedefs/typedefs_efm32.h"
#include "delay.h"

/**
 * Defines and constants section ----------------------------------------------
**/


/**
 * Module variable section ----------------------------------------------------
**/


/**
 * Function prototypes section ------------------------------------------------
**/
// Add function prototypes here
void DELAY_ms(uint32_t dlyTicks);
void ASM_WAIT_us(uint32_t uiArg);
void DELAY_us( uint32_t u32_us );

/**
 *  Function section ----------------------------------------------------------
**/

/**
 * \brief Delays number of us
 *
 * \param u32_us number of microseconds to wait
 *
**/ 
void ASM_WAIT_us(uint32_t uiArg)
{
	__asm(
		"loop:\n"
		"SUBS uiArg, uiArg, #1\n"
		"CMP uiArg, #0x00\n"
		"BNE loop\n"
	);

}


/**
 * \brief Delays number of us
 *
 * \param u32_us number of microseconds to wait
 *
**/ 
void DELAY_us( uint32_t u32_us )
{
 	uint32_t delay;
	
	if( u32_us <= (50 / INSTRUCTIONS_PER_1US) )
	{
		return;
	}
	
	delay = ( (u32_us * INSTRUCTIONS_PER_1US) - 50 ) / INSTRUCTIONS_PER_LOOP;
	
	ASM_WAIT_us(delay);
}


/**
 * \brief Delays number of ms
 *
 * \param dlyTicks number of milliseconds to wait
 *
**/ 
void DELAY_ms(uint32_t dlyTicks)
{
	while (dlyTicks--) 
	{
		DELAY_us( 1000 );
	}
}

/** \}
 * End of file
**/
