/**
 * \file    demo.c
 * \brief   Demomodul fr EPD Displays
 * \author  eQ-3 Entwicklung GmbH
**/
/*-----------------------------------------------------------------------------
 * Copyright 2016 eQ-3 Entwicklung GmbH
 * All Rights Reserved.
 *
 * The information contained in this file is confidential property of "eQ-3
 * Entwicklung GmbH". The use copying, transfer or disclosure is prohibited
 * except by written agreement with "eQ-3 Entwicklung GmbH".
 *---------------------------------------------------------------------------*/
/*
 * $URL$
 * $Author$
 * $Date$
 * $Revision$
 */

/** @addtogroup DEMO
 *  @{
**/
/*---------------------------------------------------------------------------*/
 
/**
 * Includes section -----------------------------------------------------------
**/
#include "em_emu.h"
#include "em_cmu.h"
#include "em_int.h"

#include "defines.h"
#include "../delay/delay.h"
#include "../gpio/gpio.h"
#include "../display/15WG1/15WG1_EPD.h"
#include "../display/15WG1/15WG1_SPI.h"

/**
 * Defines and constants section ----------------------------------------------
**/
const uint8_t pic1[]=     // ELV Logo
{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 127, 255, 255, 255, 255, 255, 255, 132, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 127, 255, 255, 255, 255, 255, 254, 4, 0, 0, 0, 0, 16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 127, 255, 255, 255, 255, 255, 252, 6, 0, 0, 0, 0, 28, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 127, 255, 255, 255, 255, 255, 248, 7, 0, 0, 0, 0, 30, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 127, 255, 255, 255, 255, 255, 240, 7, 0, 0, 0, 0, 31, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 127, 255, 255, 255, 255, 255, 224, 7, 128, 0, 0, 0, 31, 192, 0, 0, 0, 0, 0, 31, 0, 0, 0, 0, 0, 127, 255, 255, 255, 255, 255, 192, 15, 192, 0, 0, 0, 31, 224, 0, 0, 0, 0, 0, 63, 0, 0, 0, 0, 0, 127, 255, 255, 255, 255, 255, 128, 15, 224, 0, 0, 0, 31, 248, 0, 0, 0, 0, 0, 255, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 255, 0, 15, 224, 0, 0, 0, 31, 252, 0, 0, 0, 0, 1, 254, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 254, 0, 15, 240, 0, 0, 0, 31, 255, 0, 0, 0, 0, 7, 254, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 252, 0, 15, 248, 0, 0, 0, 31, 255, 128, 0, 0, 0, 15, 254, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 248, 0, 15, 252, 0, 0, 0, 31, 255, 192, 0, 0, 0, 63, 254, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 224, 0, 15, 252, 0, 0, 0, 15, 255, 240, 0, 0, 0, 127, 252, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 192, 0, 31, 254, 0, 0, 0, 15, 255, 240, 0, 0, 1, 255, 252, 0, 0, 0, 0, 0, 255, 252, 0, 0, 0, 0, 0, 31, 255, 0, 0, 0, 15, 255, 240, 0, 0, 3, 255, 252, 0, 0, 0, 0, 1, 255, 252, 0, 0, 0, 0, 0, 31, 255, 128, 0, 0, 15, 255, 240, 0, 0, 7, 255, 248, 0, 0, 0, 0, 1, 255, 252, 0, 0, 0, 0, 0, 31, 255, 128, 0, 0, 15, 255, 240, 0, 0, 7, 255, 248, 0, 0, 0, 0, 1, 255, 252, 0, 0, 0, 0, 0, 31, 255, 192, 0, 0, 15, 255, 240, 0, 0, 7, 255, 248, 0, 0, 0, 0, 1, 255, 248, 0, 0, 0, 0, 0, 31, 255, 192, 0, 0, 15, 255, 240, 0, 0, 15, 255, 248, 0, 0, 0, 0, 1, 255, 248, 0, 0, 0, 0, 0, 63, 255, 192, 0, 0, 15, 255, 248, 0, 0, 15, 255, 240, 0, 0, 0, 0, 1, 255, 248, 0, 0, 0, 0, 0, 63, 255, 192, 0, 0, 15, 255, 248, 0, 0, 15, 255, 240, 0, 0, 0, 0, 1, 255, 248, 0, 0, 0, 0, 0, 63, 255, 192, 0, 0, 15, 255, 248, 0, 0, 15, 255, 240, 0, 0, 0, 0, 1, 255, 248, 0, 0, 0, 0, 0, 63, 255, 128, 0, 0, 15, 255, 248, 0, 0, 31, 255, 240, 0, 0, 0, 0, 3, 255, 248, 0, 0, 0, 0, 0, 63, 255, 128, 0, 0, 7, 255, 248, 0, 0, 31, 255, 224, 0, 0, 0, 0, 3, 255, 248, 0, 0, 0, 0, 0, 63, 255, 128, 0, 0, 7, 255, 248, 0, 0, 31, 255, 224, 0, 0, 0, 0, 3, 255, 248, 0, 0, 0, 0, 0, 63, 255, 128, 0, 0, 7, 255, 248, 0, 0, 31, 255, 224, 0, 0, 0, 0, 3, 255, 240, 0, 0, 0, 0, 0, 127, 255, 128, 0, 0, 7, 255, 248, 0, 0, 63, 255, 224, 0, 0, 0, 0, 3, 255, 240, 0, 0, 0, 0, 0, 127, 255, 128, 0, 0, 7, 255, 248, 0, 0, 63, 255, 192, 0, 0, 0, 0, 3, 255, 240, 0, 0, 0, 0, 0, 127, 255, 0, 0, 0, 7, 255, 248, 0, 0, 63, 255, 192, 0, 0, 0, 0, 3, 255, 240, 0, 0, 0, 0, 0, 127, 255, 0, 0, 0, 7, 255, 248, 0, 0, 63, 255, 192, 0, 0, 0, 0, 3, 255, 240, 0, 0, 0, 0, 0, 127, 255, 0, 0, 0, 7, 255, 248, 0, 0, 127, 255, 192, 0, 0, 0, 0, 7, 255, 240, 0, 0, 0, 0, 0, 127, 255, 0, 0, 0, 7, 255, 252, 0, 0, 127, 255, 128, 0, 0, 0, 0, 7, 255, 240, 0, 0, 0, 0, 0, 255, 255, 0, 0, 0, 7, 255, 252, 0, 0, 127, 255, 128, 0, 0, 0, 0, 7, 255, 224, 0, 0, 0, 0, 0, 255, 255, 0, 0, 0, 7, 255, 252, 0, 0, 127, 255, 128, 0, 0, 0, 0, 7, 255, 224, 0, 0, 0, 0, 0, 255, 254, 0, 0, 0, 3, 255, 252, 0, 0, 255, 255, 0, 0, 0, 0, 0, 7, 255, 224, 0, 0, 0, 0, 0, 255, 254, 0, 0, 0, 3, 255, 252, 0, 0, 255, 255, 0, 0, 0, 0, 0, 7, 255, 224, 0, 0, 0, 0, 0, 255, 254, 0, 0, 0, 3, 255, 252, 0, 0, 255, 255, 0, 0, 0, 0, 0, 7, 255, 224, 0, 0, 0, 0, 0, 255, 254, 0, 0, 0, 3, 255, 252, 0, 0, 255, 255, 0, 0, 0, 0, 0, 7, 255, 224, 0, 0, 0, 0, 0, 255, 254, 0, 0, 0, 3, 255, 252, 0, 1, 255, 254, 0, 0, 0, 0, 0, 15, 255, 224, 0, 0, 0, 0, 1, 255, 254, 0, 0, 0, 3, 255, 252, 0, 1, 255, 254, 0, 0, 0, 0, 0, 15, 255, 192, 0, 0, 0, 0, 1, 255, 252, 0, 0, 0, 3, 255, 252, 0, 1, 255, 254, 0, 0, 0, 0, 0, 15, 255, 192, 0, 0, 0, 0, 1, 255, 252, 0, 0, 0, 3, 255, 252, 0, 1, 255, 254, 0, 0, 0, 0, 0, 15, 255, 192, 0, 0, 0, 0, 1, 255, 252, 0, 0, 0, 3, 255, 252, 0, 3, 255, 252, 0, 0, 0, 0, 0, 7, 255, 192, 0, 0, 0, 0, 1, 255, 252, 0, 0, 0, 3, 255, 254, 0, 3, 255, 252, 0, 0, 0, 0, 0, 7, 255, 255, 255, 255, 240, 0, 0, 255, 252, 0, 0, 0, 3, 255, 254, 0, 3, 255, 252, 0, 0, 0, 0, 0, 3, 255, 255, 255, 255, 248, 0, 0, 255, 252, 0, 0, 0, 0, 255, 254, 0, 3, 255, 252, 0, 0, 0, 0, 0, 1, 255, 255, 255, 255, 252, 0, 0, 127, 252, 0, 0, 0, 0, 127, 252, 0, 1, 255, 248, 0, 0, 0, 0, 0, 1, 255, 255, 255, 255, 254, 0, 0, 63, 248, 0, 0, 0, 0, 63, 248, 0, 1, 255, 224, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 0, 0, 63, 224, 0, 0, 0, 0, 15, 240, 0, 0, 255, 192, 0, 0, 0, 0, 0, 0, 127, 255, 255, 255, 255, 128, 0, 31, 192, 0, 0, 0, 0, 7, 224, 0, 1, 255, 0, 0, 0, 0, 0, 0, 0, 127, 255, 255, 255, 255, 192, 0, 63, 0, 0, 0, 0, 0, 3, 240, 0, 3, 254, 0, 0, 0, 0, 0, 0, 1, 255, 255, 255, 255, 255, 128, 0, 127, 128, 0, 0, 0, 0, 7, 248, 0, 15, 255, 0, 0, 0, 0, 0, 0, 3, 255, 255, 255, 255, 255, 0, 1, 255, 128, 0, 0, 0, 0, 15, 252, 0, 15, 255, 0, 0, 0, 0, 0, 0, 7, 255, 255, 255, 255, 254, 0, 3, 255, 192, 0, 0, 0, 0, 31, 255, 0, 15, 255, 128, 0, 0, 0, 0, 0, 15, 255, 255, 255, 255, 252, 0, 7, 255, 224, 0, 0, 0, 0, 63, 255, 0, 31, 255, 128, 0, 0, 0, 0, 0, 31, 255, 255, 255, 255, 248, 0, 7, 255, 240, 0, 0, 0, 0, 127, 255, 0, 31, 255, 192, 0, 0, 0, 0, 0, 63, 255, 255, 255, 255, 240, 0, 7, 255, 240, 0, 0, 0, 0, 255, 255, 0, 31, 255, 192, 0, 0, 0, 0, 0, 63, 255, 255, 255, 255, 224, 0, 7, 255, 240, 0, 0, 0, 0, 255, 255, 0, 31, 255, 192, 0, 0, 0, 0, 0, 63, 255, 0, 0, 0, 0, 0, 7, 255, 240, 0, 0, 0, 0, 255, 255, 0, 63, 255, 192, 0, 0, 0, 0, 0, 63, 255, 0, 0, 0, 0, 0, 15, 255, 224, 0, 0, 0, 0, 255, 255, 0, 63, 255, 192, 0, 0, 0, 0, 0, 63, 255, 0, 0, 0, 0, 0, 15, 255, 224, 0, 0, 0, 0, 255, 255, 0, 63, 255, 128, 0, 0, 0, 0, 0, 127, 254, 0, 0, 0, 0, 0, 15, 255, 224, 0, 0, 0, 0, 255, 255, 128, 63, 255, 128, 0, 0, 0, 0, 0, 127, 254, 0, 0, 0, 0, 0, 15, 255, 224, 0, 0, 0, 0, 255, 255, 128, 127, 255, 128, 0, 0, 0, 0, 0, 127, 254, 0, 0, 0, 0, 0, 15, 255, 224, 0, 0, 0, 0, 255, 255, 128, 127, 255, 128, 0, 0, 0, 0, 0, 127, 254, 0, 0, 0, 0, 0, 15, 255, 224, 0, 0, 0, 0, 127, 255, 128, 127, 255, 0, 0, 0, 0, 0, 0, 127, 254, 0, 0, 0, 0, 0, 15, 255, 192, 0, 0, 0, 0, 127, 255, 128, 255, 255, 0, 0, 0, 0, 0, 0, 127, 254, 0, 0, 0, 0, 0, 31, 255, 192, 0, 0, 0, 0, 127, 255, 128, 255, 255, 0, 0, 0, 0, 0, 0, 127, 254, 0, 0, 0, 0, 0, 31, 255, 192, 0, 0, 0, 0, 127, 255, 128, 255, 254, 0, 0, 0, 0, 0, 0, 255, 252, 0, 0, 0, 0, 0, 31, 255, 192, 0, 0, 0, 0, 127, 255, 128, 255, 254, 0, 0, 0, 0, 0, 0, 255, 252, 0, 0, 0, 0, 0, 31, 255, 192, 0, 0, 0, 0, 127, 255, 129, 255, 254, 0, 0, 0, 0, 0, 0, 255, 252, 0, 0, 0, 0, 0, 31, 255, 192, 0, 0, 0, 0, 127, 255, 193, 255, 254, 0, 0, 0, 0, 0, 0, 255, 252, 0, 0, 0, 0, 0, 31, 255, 128, 0, 0, 0, 0, 127, 255, 193, 255, 252, 0, 0, 0, 0, 0, 0, 255, 252, 0, 0, 0, 0, 0, 63, 255, 128, 0, 0, 0, 0, 127, 255, 193, 255, 252, 0, 0, 0, 0, 0, 0, 255, 252, 0, 0, 0, 0, 0, 63, 255, 128, 0, 0, 0, 0, 127, 255, 195, 255, 252, 0, 0, 0, 0, 0, 0, 255, 252, 0, 0, 0, 0, 0, 63, 255, 128, 0, 0, 0, 0, 127, 255, 195, 255, 252, 0, 0, 0, 0, 0, 0, 255, 252, 0, 0, 0, 0, 0, 63, 255, 128, 0, 0, 0, 0, 63, 255, 195, 255, 248, 0, 0, 0, 0, 0, 1, 255, 248, 0, 0, 0, 0, 0, 63, 255, 128, 0, 0, 0, 0, 63, 255, 199, 255, 248, 0, 0, 0, 0, 0, 1, 255, 248, 0, 0, 0, 0, 0, 63, 255, 0, 0, 0, 0, 0, 63, 255, 199, 255, 248, 0, 0, 0, 0, 0, 1, 255, 248, 0, 0, 0, 0, 0, 63, 255, 0, 0, 0, 0, 0, 63, 255, 199, 255, 248, 0, 0, 0, 0, 0, 1, 255, 248, 0, 0, 0, 0, 0, 127, 255, 0, 0, 0, 0, 0, 63, 255, 231, 255, 240, 0, 0, 0, 0, 0, 1, 255, 248, 0, 0, 0, 0, 0, 127, 255, 0, 0, 0, 0, 0, 63, 255, 239, 255, 240, 0, 0, 0, 0, 0, 1, 255, 248, 0, 0, 0, 0, 0, 127, 255, 0, 0, 0, 0, 0, 63, 255, 239, 255, 240, 0, 0, 0, 0, 0, 1, 255, 248, 0, 0, 0, 0, 0, 127, 255, 0, 0, 0, 0, 0, 63, 255, 239, 255, 224, 0, 0, 0, 0, 0, 1, 255, 240, 0, 0, 0, 0, 0, 127, 254, 0, 0, 0, 0, 0, 63, 255, 255, 255, 224, 0, 0, 0, 0, 0, 3, 255, 240, 0, 0, 0, 0, 0, 127, 254, 0, 0, 0, 0, 0, 63, 255, 255, 255, 224, 0, 0, 0, 0, 0, 3, 255, 240, 0, 0, 0, 0, 0, 255, 254, 0, 0, 0, 0, 0, 63, 255, 255, 255, 224, 0, 0, 0, 0, 0, 3, 255, 240, 0, 0, 0, 0, 0, 255, 254, 0, 0, 0, 0, 0, 31, 255, 255, 255, 192, 0, 0, 0, 0, 0, 3, 255, 240, 0, 0, 0, 0, 0, 255, 254, 0, 0, 0, 0, 0, 31, 255, 223, 255, 192, 0, 0, 0, 0, 0, 3, 255, 255, 255, 255, 255, 192, 0, 255, 255, 255, 255, 255, 224, 0, 31, 255, 143, 255, 192, 0, 0, 0, 0, 0, 3, 255, 255, 255, 255, 255, 224, 0, 255, 255, 255, 255, 255, 240, 0, 31, 255, 15, 255, 192, 0, 0, 0, 0, 0, 3, 255, 255, 255, 255, 255, 224, 0, 255, 255, 255, 255, 255, 240, 0, 31, 255, 7, 255, 128, 0, 0, 0, 0, 0, 3, 255, 255, 255, 255, 255, 240, 1, 255, 255, 255, 255, 255, 248, 0, 31, 254, 7, 255, 128, 0, 0, 0, 0, 0, 7, 255, 255, 255, 255, 255, 248, 1, 255, 255, 255, 255, 255, 252, 0, 31, 252, 3, 255, 128, 0, 0, 0, 0, 0, 7, 255, 255, 255, 255, 255, 248, 1, 255, 255, 255, 255, 255, 254, 0, 31, 248, 1, 255, 128, 0, 0, 0, 0, 0, 7, 255, 255, 255, 255, 255, 252, 1, 255, 255, 255, 255, 255, 255, 0, 31, 240, 1, 255, 0, 0, 0, 0, 0, 0, 7, 255, 255, 255, 255, 255, 254, 1, 255, 255, 255, 255, 255, 255, 0, 31, 240, 0, 255, 0, 0, 0, 0, 0, 0, 7, 255, 255, 255, 255, 255, 254, 0, 255, 255, 255, 255, 255, 255, 128, 15, 224, 0, 255, 0, 0, 0, 0, 0, 0, 3, 255, 255, 255, 255, 255, 255, 0, 127, 255, 255, 255, 255, 255, 192, 15, 192, 0, 126, 0, 0, 0, 0, 0, 0, 1, 255, 255, 255, 255, 255, 255, 128, 63, 255, 255, 255, 255, 255, 224, 15, 128, 0, 126, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 255, 128, 31, 255, 255, 255, 255, 255, 240, 15, 128, 0, 62, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 255, 192, 15, 255, 255, 255, 255, 255, 248, 15, 0, 0, 62, 0, 0, 0, 0, 0, 0, 0, 127, 255, 255, 255, 255, 255, 224, 7, 255, 255, 255, 255, 255, 248, 14, 0, 0, 28, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};	
const uint8_t pic2[]=     // QR Code
{255, 255, 255, 255, 255, 255, 255, 0, 255, 0, 0, 255, 255, 255, 0, 0, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 0, 0, 255, 255, 255, 0, 0, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 0, 0, 255, 255, 255, 0, 0, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 0, 0, 255, 255, 255, 0, 0, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 0, 0, 255, 255, 255, 0, 0, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 0, 0, 255, 255, 255, 0, 0, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 0, 0, 255, 255, 255, 0, 0, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 0, 0, 255, 255, 255, 0, 0, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 255, 255, 0, 0, 255, 0, 0, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 255, 255, 0, 0, 255, 0, 0, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 255, 255, 0, 0, 255, 0, 0, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 255, 255, 0, 0, 255, 0, 0, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 255, 255, 0, 0, 255, 0, 0, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 255, 255, 0, 0, 255, 0, 0, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 255, 255, 0, 0, 255, 0, 0, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 255, 255, 0, 0, 255, 0, 0, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 255, 0, 255, 255, 0, 255, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 255, 0, 255, 255, 0, 255, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 255, 0, 255, 255, 0, 255, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 255, 0, 255, 255, 0, 255, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 255, 0, 255, 255, 0, 255, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 255, 0, 255, 255, 0, 255, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 255, 0, 255, 255, 0, 255, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 255, 0, 255, 255, 0, 255, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 255, 0, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 255, 0, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 255, 0, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 255, 0, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 255, 0, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 255, 0, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 255, 0, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 255, 0, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 255, 0, 255, 0, 0, 255, 0, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 255, 0, 255, 0, 0, 255, 0, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 255, 0, 255, 0, 0, 255, 0, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 255, 0, 255, 0, 0, 255, 0, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 255, 0, 255, 0, 0, 255, 0, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 255, 0, 255, 0, 0, 255, 0, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 255, 0, 255, 0, 0, 255, 0, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 255, 0, 255, 0, 0, 255, 0, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 0, 0, 0, 0, 0, 255, 0, 255, 255, 0, 255, 0, 255, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 0, 255, 255, 0, 255, 0, 255, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 0, 255, 255, 0, 255, 0, 255, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 0, 255, 255, 0, 255, 0, 255, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 0, 255, 255, 0, 255, 0, 255, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 0, 255, 255, 0, 255, 0, 255, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 0, 255, 255, 0, 255, 0, 255, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 0, 255, 255, 0, 255, 0, 255, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 255, 0, 0, 255, 255, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 255, 0, 0, 255, 255, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 255, 0, 0, 255, 255, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 255, 0, 0, 255, 255, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 255, 0, 0, 255, 255, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 255, 0, 0, 255, 255, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 255, 0, 0, 255, 255, 255, 0, 255, 0, 0, 0, 0, 0, 255, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 255, 0, 0, 255, 255, 255, 0, 255, 0, 0, 0, 0, 0, 255, 0, 0, 0, 255, 255, 0, 0, 0, 0, 255, 0, 0, 255, 0, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 0, 0, 0, 255, 255, 0, 0, 0, 0, 255, 0, 0, 255, 0, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 0, 0, 0, 255, 255, 0, 0, 0, 0, 255, 0, 0, 255, 0, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 0, 0, 0, 255, 255, 0, 0, 0, 0, 255, 0, 0, 255, 0, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 0, 0, 0, 255, 255, 0, 0, 0, 0, 255, 0, 0, 255, 0, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 0, 0, 0, 255, 255, 0, 0, 0, 0, 255, 0, 0, 255, 0, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 0, 0, 0, 255, 255, 0, 0, 0, 0, 255, 0, 0, 255, 0, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 0, 0, 0, 255, 255, 0, 0, 0, 0, 255, 0, 0, 255, 0, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 255, 0, 0, 255, 0, 255, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 0, 255, 0, 255, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 0, 255, 0, 255, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 0, 255, 0, 255, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 0, 255, 0, 255, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 0, 255, 0, 255, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 0, 255, 0, 255, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 0, 255, 0, 255, 255, 255, 255, 0, 255, 255, 0, 255, 255, 255, 0, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 0, 255, 0, 255, 0, 0, 255, 0, 255, 255, 255, 255, 255, 0, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 0, 255, 0, 255, 0, 0, 255, 0, 255, 255, 255, 255, 255, 0, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 0, 255, 0, 255, 0, 0, 255, 0, 255, 255, 255, 255, 255, 0, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 0, 255, 0, 255, 0, 0, 255, 0, 255, 255, 255, 255, 255, 0, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 0, 255, 0, 255, 0, 0, 255, 0, 255, 255, 255, 255, 255, 0, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 0, 255, 0, 255, 0, 0, 255, 0, 255, 255, 255, 255, 255, 0, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 0, 255, 0, 255, 0, 0, 255, 0, 255, 255, 255, 255, 255, 0, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 0, 255, 0, 255, 0, 0, 255, 0, 255, 255, 255, 255, 0, 0, 0, 0, 255, 0, 255, 0, 0, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 0, 0, 255, 0, 255, 0, 0, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 0, 0, 255, 0, 255, 0, 0, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 0, 0, 255, 0, 255, 0, 0, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 0, 0, 255, 0, 255, 0, 0, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 0, 0, 255, 0, 255, 0, 0, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 0, 0, 255, 0, 255, 0, 0, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 0, 0, 255, 0, 255, 0, 0, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 0, 0, 0, 0, 255, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 0, 0, 0, 0, 255, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 0, 0, 0, 0, 255, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 0, 0, 0, 0, 255, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 0, 0, 0, 0, 255, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 0, 0, 0, 0, 255, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 0, 0, 0, 0, 255, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 0, 0, 0, 0, 255, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 255, 255, 255, 0, 0, 0, 255, 255, 0, 0, 255, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 0, 255, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 0, 255, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 0, 255, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 0, 255, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 0, 255, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 0, 255, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 0, 255, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 255, 255, 255, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 0, 255, 255, 0, 0, 255, 0, 0, 0, 0, 255, 255, 0, 255, 0, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 0, 255, 255, 0, 0, 255, 0, 0, 0, 0, 255, 255, 0, 255, 0, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 0, 255, 255, 0, 0, 255, 0, 0, 0, 0, 255, 255, 0, 255, 0, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 0, 255, 255, 0, 0, 255, 0, 0, 0, 0, 255, 255, 0, 255, 0, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 0, 255, 255, 0, 0, 255, 0, 0, 0, 0, 255, 255, 0, 255, 0, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 0, 255, 255, 0, 0, 255, 0, 0, 0, 0, 255, 255, 0, 255, 0, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 0, 255, 255, 0, 0, 255, 0, 0, 0, 0, 255, 255, 0, 255, 0, 255, 255, 0, 255, 255, 0, 255, 0, 0, 255, 0, 255, 255, 0, 0, 255, 0, 0, 0, 0, 255, 255, 0, 255, 0, 255, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 255, 255, 255, 255, 255, 255, 0, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 255, 255, 255, 255, 255, 255, 0, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 255, 255, 255, 255, 255, 255, 0, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 255, 255, 255, 255, 255, 255, 0, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 255, 255, 255, 255, 255, 255, 0, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 255, 255, 255, 255, 255, 255, 0, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 255, 255, 255, 255, 255, 255, 0, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 255, 255, 255, 255, 255, 255, 0, 255, 255, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 0, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 0, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 0, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 0, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 0, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 0, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 0, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 0, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 0, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 0, 255, 0, 255, 0, 255, 0, 255, 255, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 0, 255, 0, 255, 0, 255, 0, 255, 255, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 0, 255, 0, 255, 0, 255, 0, 255, 255, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 0, 255, 0, 255, 0, 255, 0, 255, 255, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 0, 255, 0, 255, 0, 255, 0, 255, 255, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 0, 255, 0, 255, 0, 255, 0, 255, 255, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 0, 255, 0, 255, 0, 255, 0, 255, 255, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 255, 0, 0, 255, 0, 255, 0, 255, 0, 255, 255, 0, 0, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 255, 255, 255, 0, 255, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 255, 255, 255, 0, 255, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 255, 255, 255, 0, 255, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 255, 255, 255, 0, 255, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 255, 255, 255, 0, 255, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 255, 255, 255, 0, 255, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 255, 255, 255, 0, 255, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 255, 255, 0, 0, 0, 0, 0, 255, 0, 0, 255, 255, 255, 0, 255, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 255, 255, 0, 255, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 0, 255, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 0, 255, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 0, 255, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 0, 255, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 0, 255, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 0, 255, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 0, 255, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 255, 0, 255, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 255, 255, 255, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 255, 255, 255, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 255, 255, 255, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 255, 255, 255, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 255, 255, 255, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 255, 255, 255, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 255, 255, 255, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 255, 0, 255, 0, 255, 0, 255, 255, 255, 255, 255, 0, 255, 255, 255, 255, 0, 255, 0, 255, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 255, 255, 0, 255, 255, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 255, 255, 0, 255, 255, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 255, 255, 0, 255, 255, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 255, 255, 0, 255, 255, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 255, 255, 0, 255, 255, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 255, 255, 0, 255, 255, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 255, 255, 0, 255, 255, 255, 255, 0, 255, 255, 255, 0, 255, 0, 0, 0, 255, 255, 0, 255, 0, 0, 255, 255, 0, 255, 255, 0, 255, 255, 255, 255, 0, 0, 0, 0, 0, 255, 0, 255, 0, 0, 255, 0, 0, 255, 0, 0, 0, 255, 255, 255, 0, 255, 255, 255, 255, 0, 0, 0, 0, 0, 255, 0, 255, 0, 0, 255, 0, 0, 255, 0, 0, 0, 255, 255, 255, 0, 255, 255, 255, 255, 0, 0, 0, 0, 0, 255, 0, 255, 0, 0, 255, 0, 0, 255, 0, 0, 0, 255, 255, 255, 0, 255, 255, 255, 255, 0, 0, 0, 0, 0, 255, 0, 255, 0, 0, 255, 0, 0, 255, 0, 0, 0, 255, 255, 255, 0, 255, 255, 255, 255, 0, 0, 0, 0, 0, 255, 0, 255, 0, 0, 255, 0, 0, 255, 0, 0, 0, 255, 255, 255, 0, 255, 255, 255, 255, 0, 0, 0, 0, 0, 255, 0, 255, 0, 0, 255, 0, 0, 255, 0, 0, 0, 255, 255, 255, 0, 255, 255, 255, 255, 0, 0, 0, 0, 0, 255, 0, 255, 0, 0, 255, 0, 0, 255, 0, 0, 0, 255, 255, 255, 0, 255, 255, 255, 255, 0, 0, 0, 0, 0, 255, 0, 255, 0, 0, 255, 0, 0, 255, 0, 0, 0, 255, 255, 255, 0, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 255, 0, 0, 255, 0, 0, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 255, 0, 0, 255, 0, 0, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 255, 0, 0, 255, 0, 0, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 255, 0, 0, 255, 0, 0, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 255, 0, 0, 255, 0, 0, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 255, 0, 0, 255, 0, 0, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 255, 0, 0, 255, 0, 0, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 0, 255, 255, 0, 0, 255, 0, 0, 0, 255, 255, 0, 0, 0, 255, 0, 0, 255};	


/**
 * Function prototypes section ------------------------------------------------
**/
void EPD_15WG1_battery_sleepdemo(void);
void EPD_15WG1_functiondemo(void);
void EPD_15WG1_picturedemo (void);
void EPD_15WG1_testfontdemo(void);


/**
 *  Function section ----------------------------------------------------------
**/

/**
 * \brief Current measurement battery Demo function
 *
 * \param NONE
 * \retval NONE
**/
void EPD_15WG1_battery_sleepdemo(void)
{
	NVIC_DisableIRQ( TIMER0_IRQn );
	EMU_EnterEM2( __TRUE );
	NVIC_EnableIRQ( TIMER0_IRQn );
}


/**
 * \brief Function Demo various display functions
 *
 * \param NONE
 * \retval NONE
**/
void EPD_15WG1_functiondemo(void)
{
  EPD_15WG1_Refresh(REFMODE_1);	
  EPD_15WG1_WriteDispRamStripes(BLACK, 8);
  DELAY_ms(2000);
  EPD_15WG1_WriteDispRamStripes(WHITE, 8);		
  DELAY_ms(2000);		

  EPD_15WG1_Refresh(REFMODE_1);	
  EPD_15WG1_WriteDispRamVertikLine(DASHED, 50); 
  DELAY_ms(2000);

  EPD_15WG1_Refresh(REFMODE_1);	
  EPD_15WG1_WriteDispRamVertikLine(DASHEDTHICK, 100); 
  DELAY_ms(2000);

  EPD_15WG1_Refresh(REFMODE_1);	
  EPD_15WG1_WriteDispRamVertikLine(DASHEDTHIN, 150); 
  DELAY_ms(2000);

  EPD_15WG1_Refresh(REFMODE_1);
  EPD_15WG1_WriteDispRamChessboard(WHITE, 2, 2);
  DELAY_ms(2000);

  EPD_15WG1_Refresh(REFMODE_1);
  EPD_15WG1_WriteDispRamChessboard(BLACK, 2, 2);
  DELAY_ms(2000);

  EPD_15WG1_Refresh(REFMODE_1);	
  EPD_15WG1_WriteDispRamChessboard(BLACK, 5, 5);		
  DELAY_ms(2000);

  EPD_15WG1_Refresh(REFMODE_1);	
  EPD_15WG1_WriteDispRamChessboard(WHITE, 25, 25);
  DELAY_ms(2000);

  EPD_15WG1_Refresh(REFMODE_1);
  EPD_15WG1_WriteDispRamStripes(BLACK, 200);
  DELAY_ms(2000);

  EPD_15WG1_Refresh(REFMODE_1);
  EPD_15WG1_WriteDispRamDots(BLACKDOTS, WHITE, 200);
  DELAY_ms(2000);

  EPD_15WG1_Refresh(REFMODE_4);
 }
 
 
/**
 * \brief Function Demo with various pictures
 *
 * \param NONE
 * \retval NONE
**/
void EPD_15WG1_picturedemo (void)
{			
  EPD_15WG1_UploadDisplay(pic1, WHITE_BACK);
  DELAY_ms(3000);
  
  EPD_15WG1_Refresh(REFMODE_4);
  EPD_15WG1_UploadDisplay(pic1, BLACK_BACK);
  DELAY_ms(3000);
  
  EPD_15WG1_Refresh(REFMODE_4);
  EPD_15WG1_UploadDisplay(pic2, WHITE_BACK);
  DELAY_ms(3000);
  
  EPD_15WG1_Refresh(REFMODE_4);		
}


/** \}
 * End of file
**/
