/**
 * \file    15WG1_SPI.c
 * \brief   Display SPI routines
 * \author  eQ-3 Entwicklung GmbH
**/
/*-----------------------------------------------------------------------------
 * Copyright 2016 eQ-3 Entwicklung GmbH
 * All Rights Reserved.
 *
 * The information contained in this file is confidential property of "eQ-3
 * Entwicklung GmbH". The use copying, transfer or disclosure is prohibited
 * except by written agreement with "eQ-3 Entwicklung GmbH".
 *---------------------------------------------------------------------------*/
/*
 * $URL$
 * $Author$
 * $Date$
 * $Revision$
 */

/** @addtogroup EPD_15WG1
 *  @{
**/
/*---------------------------------------------------------------------------*/
 
/**
 * Includes section -----------------------------------------------------------
**/
#include <stdlib.h>     
#include <string.h> 	
#include "em_cmu.h"
#include "em_usart.h"
#include "defines.h"
#include "15WG1_SPI.h"
#include "15WG1_EPD.h"


/**
 * Module variable section ----------------------------------------------------
**/
static USART_TypeDef *spi;


/**
 *  Function section ----------------------------------------------------------
**/

/**
 * \brief SPI Bit numbering LSB / MSB change
 *
 * \param mode
 *    \arg LSB Least significant Byte
 *    \arg MSB Most significant Byte 
 * \return NONE
**/
void SPI_15WG1_xSB (uint16_t mode)
{
	if(mode == LSB)
	{
		spi->CTRL &= ~USART_CTRL_MSBF;
	}
  else if(mode == MSB)
	{
		spi->CTRL |= USART_CTRL_MSBF;
	}
}


/**
 * \brief SPI clock enabling and reset
 *
 * \param NONE
 * \return NONE
**/
void SPI_15WG1_init(void)
{
	/* Enabling clock USART0 */
	CMU_ClockEnable(SPI_15WG1_CLOCK, true);
	/* Enabling clock GPIO */
  CMU_ClockEnable(cmuClock_GPIO, true);
	
	USART_Reset(SPI_15WG1_USART);
}


/**
 * \brief SPI clock enabling and reset
 *
 * \param spiNumber USART number used (e.g., 1 USART1))
 * \param location GPIO Location used (e.g., 1 Location # 0)
 * \return NONE
**/
void SPI_15WG1_setup(uint8_t spiNumber, uint8_t location)
{
	USART_InitSync_TypeDef init = USART_INITSYNC_DEFAULT;
	
	GPIO_Mode_TypeDef gpioModeMosi;
  GPIO_Mode_TypeDef gpioModeMiso;
  GPIO_Mode_TypeDef gpioModeCs;
  GPIO_Mode_TypeDef gpioModeClk;
  
  switch (spiNumber)                                                      // Determining USART
  {
		case 0:
			spi = USART0;
			break;
		case 1:
			spi = USART1;
			break;
		default:
    return;
  }
	
  init.baudrate     = SPI_15WG1_BAUDRATE;                                 // Configure SPI
  init.databits     = usartDatabits8;
  init.msbf         = 1;
  init.master       = 1;
  init.clockMode    = usartClockMode0;

  USART_InitSync( spi, &init );
	
	 
  spi->ROUTE = USART_ROUTE_TXPEN | USART_ROUTE_CLKPEN | (location << 8);  // Enabling pins and setting location
  
	
	gpioModeMosi = gpioModePushPull;                                        // Set GPIO config to master
	//gpioModeMiso = gpioModeInput;                                         // No RX is required for the EPD
	gpioModeCs   = gpioModePushPull;
	gpioModeClk  = gpioModePushPull;

  switch(spiNumber)                                                       // IO configuration
  {
    case 0: switch(location)
            {
              case 0:                                                     // IO configuration (USART 0, Location #0)
                      GPIO_PinModeSet(gpioPortE, 10, gpioModeMosi, 0);    // MOSI
                      GPIO_PinModeSet(gpioPortE, 11, gpioModeMiso, 0);    // MISO
                      GPIO_PinModeSet(gpioPortE, 13, gpioModeCs,   0);    // CS
                      GPIO_PinModeSet(gpioPortE, 12, gpioModeClk,  0);    // Clock
                      break;
              case 1:                                                     // IO configuration (USART 0, Location #1)
                      GPIO_PinModeSet(gpioPortE, 7, gpioModeMosi, 0);     // MOSI
							        //GPIO_PinModeSet(gpioPortE, 6, gpioModeMiso, 0);   // MISO No RX is required for the EPD
                      GPIO_PinModeSet(gpioPortE, 4, gpioModeCs,   0);     // CS
                      GPIO_PinModeSet(gpioPortE, 5, gpioModeClk,  0);     // Clock
                      break;
              case 2:                                                     // IO configuration (USART 0, Location #2)
                      GPIO_PinModeSet(gpioPortC, 11, gpioModeMosi, 0);    // MOSI
                      GPIO_PinModeSet(gpioPortC, 10, gpioModeMiso, 0);    // MISO 
                      GPIO_PinModeSet(gpioPortC,  8, gpioModeCs,   0);    // CS
                      GPIO_PinModeSet(gpioPortC,  9, gpioModeClk,  0);    // Clock
                      break;
            default: break;
            }
            break;
    case 1: switch(location)
            {
              case 0:                                                     // IO configuration (USART 1, Location #0)
                      GPIO_PinModeSet(gpioPortC, 0, gpioModeMosi, 0);     // MOSI
                      GPIO_PinModeSet(gpioPortC, 1, gpioModeMiso, 0);     // MISO
                      GPIO_PinModeSet(gpioPortB, 8, gpioModeCs,   0);     // CS
                      GPIO_PinModeSet(gpioPortB, 7, gpioModeClk,  0);     // Clock
                      break;
              case 1:                                                     // IO configuration (USART 1, Location #1)
                      GPIO_PinModeSet(gpioPortD, 0, gpioModeMosi, 0);     // MOSI
                      GPIO_PinModeSet(gpioPortD, 1, gpioModeMiso, 0);     // MISO
                      GPIO_PinModeSet(gpioPortD, 3, gpioModeCs,   0);     // CS
                      GPIO_PinModeSet(gpioPortD, 2, gpioModeClk,  0);     // Clock
                      break;              
            default: break;
            }
            break;
    case 2: switch(location)
            {
              case 0:                                                     // IO configuration (USART 2, Location #0)
                      GPIO_PinModeSet(gpioPortC, 2, gpioModeMosi, 0);     // MOSI
                      GPIO_PinModeSet(gpioPortC, 3, gpioModeMiso, 0);     // MISO
                      GPIO_PinModeSet(gpioPortC, 5, gpioModeCs,   0);     // CS
                      GPIO_PinModeSet(gpioPortC, 4, gpioModeClk,  0);     // Clock
                      break;
              case 1:                                                     // IO configuration (USART 2, Location #1)
                      GPIO_PinModeSet(gpioPortB, 3, gpioModeMosi, 0);     // MOSI
                      GPIO_PinModeSet(gpioPortB, 4, gpioModeMiso, 0);     // MISO
                      GPIO_PinModeSet(gpioPortB, 6, gpioModeCs,   0);     // CS
                      GPIO_PinModeSet(gpioPortB, 5, gpioModeClk,  0);     // Clock
                      break;              
            default: break;
            }
            break;
    default: break;  
  }
}


/**
 * \brief SPI write function
 *
 * \param value Value to be written            
 * \return NONE
**/
void SPI_15WG1_Write(uint8_t value)                                    
{                                                              
	while((EPD_15WG1_BUSY) == 1){}                                          // Wait
  
	SPI_15WG1_SEND(value);
}


/** \}
 * End of file
**/
